[jboss-cvs] JBossAS SVN: r61043 - in projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins: deployers/helpers and 1 other directory.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Mar 2 04:13:04 EST 2007


Author: scott.stark at jboss.org
Date: 2007-03-02 04:13:04 -0500 (Fri, 02 Mar 2007)
New Revision: 61043

Modified:
   projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployer/AbstractDeploymentUnit.java
   projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/AbstractParsingDeployer.java
   projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/JAXPDeployer.java
Log:
Default to transient attachments.

Modified: projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployer/AbstractDeploymentUnit.java
===================================================================
--- projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployer/AbstractDeploymentUnit.java	2007-03-02 06:42:57 UTC (rev 61042)
+++ projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployer/AbstractDeploymentUnit.java	2007-03-02 09:13:04 UTC (rev 61043)
@@ -188,16 +188,12 @@
    }
 
    /**
-    * 
+    * Places the attachment into the transient attachments bucket.
     */
    public Object addAttachment(String name, Object attachment)
    {
       deploymentContext.deployed();
-      Object prevAttachment = null;
-      if( attachment instanceof Serializable )
-         prevAttachment = deploymentContext.getTransientManagedObjects().addAttachment(name, attachment);
-      else
-         prevAttachment = deploymentContext.getTransientAttachments().addAttachment(name, attachment);
+      Object prevAttachment = deploymentContext.getTransientAttachments().addAttachment(name, attachment);
       return prevAttachment;
    }
 

Modified: projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/AbstractParsingDeployer.java
===================================================================
--- projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/AbstractParsingDeployer.java	2007-03-02 06:42:57 UTC (rev 61042)
+++ projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/AbstractParsingDeployer.java	2007-03-02 09:13:04 UTC (rev 61043)
@@ -126,7 +126,7 @@
          return;
       
       // Register it
-      unit.getTransientManagedObjects().addAttachment(key, result, getDeploymentType());
+      unit.addAttachment(key, result, getDeploymentType());
    }
 
    /**

Modified: projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/JAXPDeployer.java
===================================================================
--- projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/JAXPDeployer.java	2007-03-02 06:42:57 UTC (rev 61042)
+++ projects/microcontainer/branches/2_0/deployers/src/main/org/jboss/deployers/plugins/deployers/helpers/JAXPDeployer.java	2007-03-02 09:13:04 UTC (rev 61043)
@@ -194,9 +194,9 @@
             }
          }
       }
       // Save dom view
       if( document != null )
-         unit.addAttachment(Document.class, document);
+         unit.getTransientManagedObjects().addAttachment(Document.class, document);
       return document;
    }
 
@@ -194,9 +194,9 @@
          }
       }
-      // Save dom view
+      // Save dom view as a managed attachment
       if( document != null )




More information about the jboss-cvs-commits mailing list